


#ifndef SRC_MISC_PAROLE_ENUM_TYPES_H_
#define SRC_MISC_PAROLE_ENUM_TYPES_H_
#include <glib-object.h>
G_BEGIN_DECLS
/* enumerations from "parole-pl-parser.h" */
#ifndef __GTK_DOC_IGNORE__
GType parole_pl_format_get_type (void);
#define PAROLE_ENUM_TYPE_PL_FORMAT (parole_pl_format_get_type())
#endif
/* enumerations from "parole-provider-player.h" */
#ifndef __GTK_DOC_IGNORE__
GType parole_plugin_container_get_type (void);
#define PAROLE_ENUM_TYPE_PLUGIN_CONTAINER (parole_plugin_container_get_type())
#endif
/* enumerations from "parole-stream.h" */
#ifndef __GTK_DOC_IGNORE__
GType parole_media_type_get_type (void);
#define PAROLE_ENUM_TYPE_MEDIA_TYPE (parole_media_type_get_type())
#endif
#ifndef __GTK_DOC_IGNORE__
GType parole_state_get_type (void);
#define PAROLE_ENUM_TYPE_STATE (parole_state_get_type())
#endif
G_END_DECLS

#endif /* SRC_MISC_PAROLE_ENUM_TYPES_H_ */



